@@ -48,6 +48,9 @@ class Hue:
         attributes = ["bridge_unique_id", "bridge_ip_address", "connection_state", "groups"]
         return generate_attribute_string(self, attributes)
 
+    def __eq__(self, other: object) -> bool:
+        return self._raw == other._raw
+
     @staticmethod
     def _build_groups(raw):
         groups = []
@@ -86,5 +89,7 @@ class Hue:
         await self._request('put', f'hue/groups/{id}', data=data)
 
     async def update(self):
-        self._raw = await self._request('get', '/hue')
-        self._groups = Hue._build_groups(self._raw)
+        response = await self._request('get', '/hue')
+        if response:
+            self._raw = response
+            self._groups = Hue._build_groups(self._raw)
